Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(426)

Unified Diff: src/ia32/builtins-ia32.cc

Issue 6992072: Implement set trap for proxies, and revamp class hierarchy in preparation (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/ia32/builtins-ia32.cc
diff --git a/src/ia32/builtins-ia32.cc b/src/ia32/builtins-ia32.cc
index 44f0a977dca4e227046c37cb8596c6fcb4ec71bd..05257099a9b71e44c5ecfc828f0c905442b8af64 100644
--- a/src/ia32/builtins-ia32.cc
+++ b/src/ia32/builtins-ia32.cc
@@ -359,8 +359,8 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm,
__ j(zero, &use_receiver);
// If the type of the result (stored in its map) is less than
- // FIRST_JS_OBJECT_TYPE, it is not an object in the ECMA sense.
- __ CmpObjectType(eax, FIRST_JS_OBJECT_TYPE, ecx);
+ // FIRST_OBJECT_OR_FUNCTION_CLASS_TYPE, it is not an object in the ECMA sense.
+ __ CmpObjectType(eax, FIRST_OBJECT_OR_FUNCTION_CLASS_TYPE, ecx);
__ j(above_equal, &exit);
// Throw away the result of the constructor invocation and use the
@@ -617,8 +617,8 @@ void Builtins::Generate_FunctionCall(MacroAssembler* masm) {
// We don't use IsObjectJSObjectType here because we jump on success.
__ mov(ecx, FieldOperand(ebx, HeapObject::kMapOffset));
__ movzx_b(ecx, FieldOperand(ecx, Map::kInstanceTypeOffset));
- __ sub(Operand(ecx), Immediate(FIRST_JS_OBJECT_TYPE));
- __ cmp(ecx, LAST_JS_OBJECT_TYPE - FIRST_JS_OBJECT_TYPE);
+ __ sub(Operand(ecx), Immediate(FIRST_OBJECT_CLASS_TYPE));
+ __ cmp(ecx, LAST_OBJECT_CLASS_TYPE - FIRST_OBJECT_CLASS_TYPE);
__ j(below_equal, &shift_arguments);
__ bind(&convert_to_object);
@@ -780,8 +780,8 @@ void Builtins::Generate_FunctionApply(MacroAssembler* masm) {
// We don't use IsObjectJSObjectType here because we jump on success.
__ mov(ecx, FieldOperand(ebx, HeapObject::kMapOffset));
__ movzx_b(ecx, FieldOperand(ecx, Map::kInstanceTypeOffset));
- __ sub(Operand(ecx), Immediate(FIRST_JS_OBJECT_TYPE));
- __ cmp(ecx, LAST_JS_OBJECT_TYPE - FIRST_JS_OBJECT_TYPE);
+ __ sub(Operand(ecx), Immediate(FIRST_OBJECT_CLASS_TYPE));
+ __ cmp(ecx, LAST_OBJECT_CLASS_TYPE - FIRST_OBJECT_CLASS_TYPE);
__ j(below_equal, &push_receiver);
// Convert the receiver to an object.

Powered by Google App Engine
This is Rietveld 408576698